@@ -1,11 +1,7 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * iplink_hsr.c	HSR device support
  *
- *		This program is free software; you can redistribute it and/or
- *		modify it under the terms of the GNU General Public License
- *		as published by the Free Software Foundation; either version
- *		2 of the License, or (at your option) any later version.
- *
  * Authors:	Arvid Brodin <arvid.brodin@alten.se>
  *
  *		Based on iplink_vlan.c by Patrick McHardy <kaber@trash.net>
