@@ -1,11 +1,7 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * link_vti6.c	VTI driver module
  *
- *		This program is free software; you can redistribute it and/or
- *		modify it under the terms of the GNU General Public License
- *		as published by the Free Software Foundation; either version
- *		2 of the License, or (at your option) any later version.
- *
  * Authors:	Herbert Xu <herbert@gondor.apana.org.au>
  *		Saurabh Mohan <saurabh.mohan@vyatta.com> Modified link_gre.c for VTI
  *		Steffen Klassert <steffen.klassert@secunet.com> Modified link_vti.c for IPv6
