@@ -1,11 +1,7 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * rt_names.c		rtnetlink names DB.
  *
- *		This program is free software; you can redistribute it and/or
- *		modify it under the terms of the GNU General Public License
- *		as published by the Free Software Foundation; either version
- *		2 of the License, or (at your option) any later version.
- *
  * Authors:	Alexey Kuznetsov, <kuznet@ms2.inr.ac.ru>
  */
 
@@ -85,6 +81,10 @@ rtnl_hash_initialize(const char *file, struct rtnl_hash_entry **hash, int size)
 			continue;
 
 		entry = malloc(sizeof(*entry));
+		if (entry == NULL) {
+			fprintf(stderr, "malloc error: for entry\n");
+			break;
+		}
 		entry->id   = id;
 		entry->name = strdup(namebuf);
 		entry->next = hash[id & (size - 1)];
@@ -230,6 +230,60 @@ int rtnl_rtprot_a2n(__u32 *id, const char *arg)
 }
 
 
+static char *rtnl_addrprot_tab[256] = {
+	[IFAPROT_UNSPEC]    = "unspec",
+	[IFAPROT_KERNEL_LO] = "kernel_lo",
+	[IFAPROT_KERNEL_RA] = "kernel_ra",
+	[IFAPROT_KERNEL_LL] = "kernel_ll",
+};
+static bool rtnl_addrprot_tab_initialized;
+
+static void rtnl_addrprot_initialize(void)
+{
+	rtnl_tab_initialize(CONFDIR "/rt_addrprotos",
+			    rtnl_addrprot_tab,
+			    ARRAY_SIZE(rtnl_addrprot_tab));
+	rtnl_addrprot_tab_initialized = true;
+}
+
+const char *rtnl_addrprot_n2a(__u8 id, char *buf, int len)
+{
+	if (numeric)
+		goto numeric;
+	if (!rtnl_addrprot_tab_initialized)
+		rtnl_addrprot_initialize();
+	if (rtnl_addrprot_tab[id])
+		return rtnl_addrprot_tab[id];
+numeric:
+	snprintf(buf, len, "%#x", id);
+	return buf;
+}
+
+int rtnl_addrprot_a2n(__u8 *id, const char *arg)
+{
+	unsigned long res;
+	char *end;
+	int i;
+
+	if (!rtnl_addrprot_tab_initialized)
+		rtnl_addrprot_initialize();
+
+	for (i = 0; i < 256; i++) {
+		if (rtnl_addrprot_tab[i] &&
+		    strcmp(rtnl_addrprot_tab[i], arg) == 0) {
+			*id = i;
+			return 0;
+		}
+	}
+
+	res = strtoul(arg, &end, 0);
+	if (!end || end == arg || *end || res > 255)
+		return -1;
+	*id = res;
+	return 0;
+}
+
+
 static char *rtnl_rtscope_tab[256] = {
 	[RT_SCOPE_UNIVERSE]	= "global",
 	[RT_SCOPE_NOWHERE]	= "nowhere",
@@ -479,18 +533,30 @@ static void rtnl_rtdsfield_initialize(void)
 
 const char *rtnl_dsfield_n2a(int id, char *buf, int len)
 {
+	const char *name;
+
 	if (id < 0 || id >= 256) {
 		snprintf(buf, len, "%d", id);
 		return buf;
 	}
+	if (!numeric) {
+		name = rtnl_dsfield_get_name(id);
+		if (name != NULL)
+			return name;
+	}
+	snprintf(buf, len, "0x%02x", id);
+	return buf;
+}
+
+const char *rtnl_dsfield_get_name(int id)
+{
+	if (id < 0 || id >= 256)
+		return NULL;
 	if (!rtnl_rtdsfield_tab[id]) {
 		if (!rtnl_rtdsfield_init)
 			rtnl_rtdsfield_initialize();
 	}
-	if (!numeric && rtnl_rtdsfield_tab[id])
-		return rtnl_rtdsfield_tab[id];
-	snprintf(buf, len, "0x%02x", id);
-	return buf;
+	return rtnl_rtdsfield_tab[id];
 }
 
 
